/* collection-view.c generated by valac 0.25.2.7-aa52, the Vala compiler
 * generated from collection-view.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libgd/gd.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesCollectionViewPrivate BoxesCollectionViewPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_CATEGORY (boxes_category_get_type ())
#define BOXES_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CATEGORY, BoxesCategory))
#define BOXES_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CATEGORY, BoxesCategoryClass))
#define BOXES_IS_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CATEGORY))
#define BOXES_IS_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CATEGORY))
#define BOXES_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CATEGORY, BoxesCategoryClass))

typedef struct _BoxesCategory BoxesCategory;
typedef struct _BoxesCategoryClass BoxesCategoryClass;

#define BOXES_COLLECTION_VIEW_TYPE_MODEL_COLUMNS (boxes_collection_view_model_columns_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block17Data Block17Data;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define _gtk_icon_info_free0(var) ((var == NULL) ? NULL : (var = (gtk_icon_info_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block18Data Block18Data;
typedef struct _Block19Data Block19Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
typedef struct _Block20Data Block20Data;
typedef struct _Block21Data Block21Data;

#define BOXES_CATEGORY_TYPE_KIND (boxes_category_kind_get_type ())

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionView {
	GdMainView parent_instance;
	BoxesCollectionViewPrivate * priv;
};

struct _BoxesCollectionViewClass {
	GdMainViewClass parent_class;
};

struct _BoxesCollectionViewPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	BoxesAppWindow* window;
	BoxesCategory* _category;
	GtkListStore* store;
	GtkTreeModelFilter* model_filter;
};

typedef enum  {
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT = GD_MAIN_COLUMN_ICON,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE = GD_MAIN_COLUMN_PRIMARY_TEXT,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO = GD_MAIN_COLUMN_SECONDARY_TEXT,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED = GD_MAIN_COLUMN_SELECTED,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE = GD_MAIN_COLUMN_PULSE,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM = GD_MAIN_COLUMN_LAST,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST
} BoxesCollectionViewModelColumns;

struct _Block17Data {
	int _ref_count_;
	BoxesCollectionView* self;
	BoxesAppWindow* window;
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _Block18Data {
	int _ref_count_;
	BoxesCollectionView* self;
	BoxesMachine* machine;
	GtkTreeIter iter;
	BoxesCollectionItem* item;
};

struct _Block19Data {
	int _ref_count_;
	BoxesCollectionView* self;
	GList* selected;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _Block20Data {
	int _ref_count_;
	BoxesCollectionView* self;
	BoxesSelectionCriteria selection;
};

struct _Block21Data {
	int _ref_count_;
	BoxesCollectionView* self;
	gint pulse;
	BoxesMachine* machine;
};

typedef enum  {
	BOXES_CATEGORY_KIND_USER,
	BOXES_CATEGORY_KIND_NEW,
	BOXES_CATEGORY_KIND_FAVORITES,
	BOXES_CATEGORY_KIND_PRIVATE,
	BOXES_CATEGORY_KIND_SHARED
} BoxesCategoryKind;


static gpointer boxes_collection_view_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static BoxesUIIface* boxes_collection_view_boxes_ui_parent_iface = NULL;

GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_category_get_type (void) G_GNUC_CONST;
#define BOXES_COLLECTION_VIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewPrivate))
enum  {
	BOXES_COLLECTION_VIEW_DUMMY_PROPERTY,
	BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE,
	BOXES_COLLECTION_VIEW_UI_STATE,
	BOXES_COLLECTION_VIEW_CATEGORY
};
static GType boxes_collection_view_model_columns_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
void boxes_collection_view_setup_ui (BoxesCollectionView* self, BoxesAppWindow* window);
static Block17Data* block17_data_ref (Block17Data* _data17_);
static void block17_data_unref (void * _userdata_);
static void __lambda7_ (Block17Data* _data17_);
gboolean boxes_app_window_get_selection_mode (BoxesAppWindow* self);
static void ___lambda7__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_collection_view_ui_state_changed (BoxesCollectionView* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void boxes_collection_view_update_screenshot (BoxesCollectionView* self, GtkTreeIter* iter);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
GIcon* boxes_create_symbolic_emblem (const gchar* name);
static void _vala_array_add3 (GIcon*** array, int* length, int* size, GIcon* value);
static void boxes_collection_view_append (BoxesCollectionView* self, const gchar* title, const gchar* info, BoxesCollectionItem* item, GtkTreeIter* result);
static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self);
void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static Block18Data* block18_data_ref (Block18Data* _data18_);
static void block18_data_unref (void * _userdata_);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
const gchar* boxes_machine_get_info (BoxesMachine* self);
static void __lambda8_ (Block18Data* _data18_);
static void ___lambda8__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda9_ (Block18Data* _data18_);
static void ___lambda9__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda10_ (Block18Data* _data18_);
static void ___lambda10__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda11_ (Block18Data* _data18_);
static void ___lambda11__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_collection_view_setup_activity (BoxesCollectionView* self, GtkTreeIter* iter, BoxesMachine* machine);
static void __lambda13_ (Block18Data* _data18_);
static void ___lambda13__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self);
static Block19Data* block19_data_ref (Block19Data* _data19_);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void block19_data_unref (void * _userdata_);
static gboolean __lambda14_ (Block19Data* _data19_, GtkTreeModel* store, GtkTreePath* path, GtkTreeIter* iter);
static gboolean ___lambda14__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static BoxesCollectionItem* boxes_collection_view_get_item_for_iter (BoxesCollectionView* self, GtkTreeIter* iter);
static BoxesCollectionItem* boxes_collection_view_get_item_for_path (BoxesCollectionView* self, GtkTreePath* path);
static gboolean boxes_collection_view_model_visible (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* iter);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
gboolean boxes_collection_filter_filter (BoxesCollectionFilter* self, BoxesCollectionItem* item);
void boxes_collection_view_refilter (BoxesCollectionView* self);
void boxes_collection_view_activate_first_item (BoxesCollectionView* self);
static void boxes_collection_view_setup_view (BoxesCollectionView* self);
static gint __lambda15_ (BoxesCollectionView* self, GtkTreeModel* store, GtkTreeIter* a, GtkTreeIter* b);
gint boxes_collection_item_compare (BoxesCollectionItem* self, BoxesCollectionItem* other);
static gint ___lambda15__gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self);
static void __lambda16_ (BoxesCollectionView* self);
static void ___lambda16__gtk_tree_model_row_deleted (GtkTreeModel* _sender, GtkTreePath* path, gpointer self);
static void __lambda17_ (BoxesCollectionView* self);
static void ___lambda17__gtk_tree_model_row_inserted (GtkTreeModel* _sender, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
static gboolean _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self);
static void __lambda18_ (BoxesCollectionView* self, GdMainView* view, const gchar* id, GtkTreePath* path);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
void boxes_app_window_select_item (BoxesAppWindow* self, BoxesCollectionItem* item);
static void ___lambda18__gd_main_view_item_activated (GdMainView* _sender, const gchar* object, GtkTreePath* p0, gpointer self);
static void __lambda157_ (BoxesCollectionView* self);
static void ___lambda157__gd_main_view_view_selection_changed (GdMainView* _sender, gpointer self);
static void __lambda158_ (BoxesCollectionView* self);
void boxes_app_window_set_selection_mode (BoxesAppWindow* self, gboolean value);
static void ___lambda158__gd_main_view_selection_mode_request (GdMainView* _sender, gpointer self);
void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection);
static Block20Data* block20_data_ref (Block20Data* _data20_);
static void block20_data_unref (void * _userdata_);
static gboolean __lambda159_ (Block20Data* _data20_, GtkTreeModel* filter_model, GtkTreePath* filter_path, GtkTreeIter* filter_iter);
gboolean boxes_machine_is_running (BoxesMachine* self);
static gboolean ___lambda159__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
static Block21Data* block21_data_ref (Block21Data* _data21_);
static void block21_data_unref (void * _userdata_);
gboolean boxes_machine_get_under_construction (BoxesMachine* self);
static gboolean __lambda12_ (Block21Data* _data21_);
static gboolean ___lambda12__gsource_func (gpointer self);
BoxesCollectionView* boxes_collection_view_new (void);
BoxesCollectionView* boxes_collection_view_construct (GType object_type);
BoxesCategory* boxes_collection_view_get_category (BoxesCollectionView* self);
void boxes_collection_view_set_category (BoxesCollectionView* self, BoxesCategory* value);
static GObject * boxes_collection_view_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType boxes_category_kind_get_type (void) G_GNUC_CONST;
BoxesCategory* boxes_category_new (const gchar* name, BoxesCategoryKind kind);
BoxesCategory* boxes_category_construct (GType object_type, const gchar* name, BoxesCategoryKind kind);
static void _boxes_collection_view_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_collection_view_finalize (GObject* obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _vala_boxes_collection_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_collection_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


GType boxes_selection_criteria_get_type (void) {
	static volatile gsize boxes_selection_criteria_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_selection_criteria_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SELECTION_CRITERIA_ALL, "BOXES_SELECTION_CRITERIA_ALL", "all"}, {BOXES_SELECTION_CRITERIA_NONE, "BOXES_SELECTION_CRITERIA_NONE", "none"}, {BOXES_SELECTION_CRITERIA_RUNNING, "BOXES_SELECTION_CRITERIA_RUNNING", "running"}, {0, NULL, NULL}};
		GType boxes_selection_criteria_type_id;
		boxes_selection_criteria_type_id = g_enum_register_static ("BoxesSelectionCriteria", values);
		g_once_init_leave (&boxes_selection_criteria_type_id__volatile, boxes_selection_criteria_type_id);
	}
	return boxes_selection_criteria_type_id__volatile;
}


static GType boxes_collection_view_model_columns_get_type (void) {
	static volatile gsize boxes_collection_view_model_columns_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_view_model_columns_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT", "screenshot"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE", "title"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO", "info"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED", "selected"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE", "pulse"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM", "item"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_collection_view_model_columns_type_id;
		boxes_collection_view_model_columns_type_id = g_enum_register_static ("BoxesCollectionViewModelColumns", values);
		g_once_init_leave (&boxes_collection_view_model_columns_type_id__volatile, boxes_collection_view_model_columns_type_id);
	}
	return boxes_collection_view_model_columns_type_id__volatile;
}


static gpointer _g_object_ref0 (gpointer self) {
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return self ? g_object_ref (self) : NULL;
#line 475 "collection-view.c"
}


static Block17Data* block17_data_ref (Block17Data* _data17_) {
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data17_->_ref_count_);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return _data17_;
#line 484 "collection-view.c"
}


static void block17_data_unref (void * _userdata_) {
	Block17Data* _data17_;
	_data17_ = (Block17Data*) _userdata_;
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data17_->_ref_count_)) {
#line 493 "collection-view.c"
		BoxesCollectionView* self;
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		self = _data17_->self;
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data17_->window);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block17Data, _data17_);
#line 503 "collection-view.c"
	}
}


static void __lambda7_ (Block17Data* _data17_) {
	BoxesCollectionView* self;
	BoxesAppWindow* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	BoxesAppWindow* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
#line 47 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = _data17_->self;
#line 48 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data17_->window;
#line 48 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_app_window_get_selection_mode (_tmp0_);
#line 48 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _tmp1_;
#line 48 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_selection_mode ((GdMainView*) self, _tmp2_);
#line 49 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _data17_->window;
#line 49 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = boxes_app_window_get_selection_mode (_tmp3_);
#line 49 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp5_ = _tmp4_;
#line 49 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (!_tmp5_) {
#line 50 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		gd_main_view_unselect_all ((GdMainView*) self);
#line 536 "collection-view.c"
	}
}


static void ___lambda7__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 47 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	__lambda7_ (self);
#line 544 "collection-view.c"
}


void boxes_collection_view_setup_ui (BoxesCollectionView* self, BoxesAppWindow* window) {
	Block17Data* _data17_;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesAppWindow* _tmp4_ = NULL;
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (window != NULL);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data17_ = g_slice_new0 (Block17Data);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data17_->_ref_count_ = 1;
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data17_->self = g_object_ref (self);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = window;
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_data17_->window);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data17_->window = _tmp1_;
#line 45 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data17_->window;
#line 45 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 45 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->window);
#line 45 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self->priv->window = _tmp3_;
#line 47 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _data17_->window;
#line 47 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_signal_connect_data ((GObject*) _tmp4_, "notify::selection-mode", (GCallback) ___lambda7__g_object_notify, block17_data_ref (_data17_), (GClosureNotify) block17_data_unref, 0);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	block17_data_unref (_data17_);
#line 44 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data17_ = NULL;
#line 589 "collection-view.c"
}


static void boxes_collection_view_ui_state_changed (BoxesCollectionView* self) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
#line 54 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 55 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 55 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _tmp0_;
#line 55 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ == BOXES_UI_STATE_COLLECTION) {
#line 56 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		gd_main_view_unselect_all ((GdMainView*) self);
#line 606 "collection-view.c"
	}
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	for (i = 0; i < stack_length; i++) {
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			return TRUE;
#line 619 "collection-view.c"
		}
	}
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return FALSE;
#line 624 "collection-view.c"
}


static void _vala_array_add3 (GIcon*** array, int* length, int* size, GIcon* value) {
#line 69 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if ((*length) == (*size)) {
#line 69 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 69 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		*array = g_renew (GIcon*, *array, (*size) + 1);
#line 635 "collection-view.c"
	}
#line 69 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	(*array)[(*length)++] = value;
#line 69 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	(*array)[*length] = NULL;
#line 641 "collection-view.c"
}


static void boxes_collection_view_update_screenshot (BoxesCollectionView* self, GtkTreeIter* iter) {
	BoxesCollectionItem* item = NULL;
	GIcon** emblem_icons = NULL;
	GIcon** _tmp0_ = NULL;
	gint emblem_icons_length1 = 0;
	gint _emblem_icons_size_ = 0;
	GtkListStore* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	BoxesMachine* machine = NULL;
	BoxesCollectionItem* _tmp3_ = NULL;
	BoxesMachine* _tmp4_ = NULL;
	BoxesMachine* _tmp5_ = NULL;
	GdkPixbuf* pixbuf = NULL;
	BoxesMachine* _tmp6_ = NULL;
	GdkPixbuf* _tmp7_ = NULL;
	GdkPixbuf* _tmp8_ = NULL;
	GdkPixbuf* _tmp9_ = NULL;
	BoxesMachine* _tmp10_ = NULL;
	BoxesBoxConfig* _tmp11_ = NULL;
	gchar** _tmp12_ = NULL;
	gint _tmp12__length1 = 0;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	gchar** _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
	gboolean _tmp15_ = FALSE;
	GIcon** _tmp18_ = NULL;
	gint _tmp18__length1 = 0;
	GtkListStore* _tmp48_ = NULL;
	GtkTreeIter _tmp49_ = {0};
	GdkPixbuf* _tmp50_ = NULL;
	GError * _inner_error_ = NULL;
#line 59 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 59 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (iter != NULL);
#line 61 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = g_new0 (GIcon*, 0 + 1);
#line 61 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	emblem_icons = _tmp0_;
#line 61 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	emblem_icons_length1 = 0;
#line 61 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_emblem_icons_size_ = emblem_icons_length1;
#line 63 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->store;
#line 63 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = *iter;
#line 63 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp1_, &_tmp2_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 64 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = item;
#line 64 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp3_) : NULL);
#line 64 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	machine = _tmp4_;
#line 65 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp5_ = machine;
#line 65 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (_tmp5_ != NULL);
#line 66 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp6_ = machine;
#line 66 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp7_ = boxes_machine_get_pixbuf (_tmp6_);
#line 66 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp8_ = _tmp7_;
#line 66 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _g_object_ref0 (_tmp8_);
#line 66 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	pixbuf = _tmp9_;
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp10_ = machine;
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp11_ = _tmp10_->config;
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp12_ = boxes_box_config_get_categories (_tmp11_, &_tmp12__length1);
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp13_ = _tmp12_;
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp13__length1 = _tmp12__length1;
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp14_ = _tmp13_;
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp14__length1 = _tmp13__length1;
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp15_ = _vala_string_array_contains (_tmp14_, _tmp13__length1, "favorite");
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp14_ = (_vala_array_free (_tmp14_, _tmp14__length1, (GDestroyNotify) g_free), NULL);
#line 68 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp15_) {
#line 735 "collection-view.c"
		GIcon** _tmp16_ = NULL;
		gint _tmp16__length1 = 0;
		GIcon* _tmp17_ = NULL;
#line 69 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp16_ = emblem_icons;
#line 69 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp16__length1 = emblem_icons_length1;
#line 69 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp17_ = boxes_create_symbolic_emblem ("emblem-favorite");
#line 69 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_vala_array_add3 (&emblem_icons, &emblem_icons_length1, &_emblem_icons_size_, _tmp17_);
#line 747 "collection-view.c"
	}
#line 71 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp18_ = emblem_icons;
#line 71 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp18__length1 = emblem_icons_length1;
#line 71 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp18__length1 > 0) {
#line 755 "collection-view.c"
		GEmblemedIcon* emblemed_icon = NULL;
		GdkPixbuf* _tmp19_ = NULL;
		GEmblemedIcon* _tmp20_ = NULL;
		GIcon** _tmp21_ = NULL;
		gint _tmp21__length1 = 0;
		GtkIconTheme* theme = NULL;
		GtkIconTheme* _tmp27_ = NULL;
		GtkIconTheme* _tmp28_ = NULL;
#line 72 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp19_ = pixbuf;
#line 72 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp20_ = (GEmblemedIcon*) g_emblemed_icon_new ((GIcon*) _tmp19_, NULL);
#line 72 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		emblemed_icon = _tmp20_;
#line 73 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp21_ = emblem_icons;
#line 73 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp21__length1 = emblem_icons_length1;
#line 774 "collection-view.c"
		{
			GIcon** emblem_icon_collection = NULL;
			gint emblem_icon_collection_length1 = 0;
			gint _emblem_icon_collection_size_ = 0;
			gint emblem_icon_it = 0;
#line 73 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			emblem_icon_collection = _tmp21_;
#line 73 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			emblem_icon_collection_length1 = _tmp21__length1;
#line 73 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			for (emblem_icon_it = 0; emblem_icon_it < _tmp21__length1; emblem_icon_it = emblem_icon_it + 1) {
#line 786 "collection-view.c"
				GIcon* _tmp22_ = NULL;
				GIcon* emblem_icon = NULL;
#line 73 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
				_tmp22_ = _g_object_ref0 (emblem_icon_collection[emblem_icon_it]);
#line 73 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
				emblem_icon = _tmp22_;
#line 793 "collection-view.c"
				{
					GEmblemedIcon* _tmp23_ = NULL;
					GIcon* _tmp24_ = NULL;
					GEmblem* _tmp25_ = NULL;
					GEmblem* _tmp26_ = NULL;
#line 74 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
					_tmp23_ = emblemed_icon;
#line 74 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
					_tmp24_ = emblem_icon;
#line 74 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
					_tmp25_ = g_emblem_new (_tmp24_);
#line 74 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
					_tmp26_ = _tmp25_;
#line 74 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
					g_emblemed_icon_add_emblem (_tmp23_, _tmp26_);
#line 74 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
					_g_object_unref0 (_tmp26_);
#line 73 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
					_g_object_unref0 (emblem_icon);
#line 813 "collection-view.c"
				}
			}
		}
#line 76 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp27_ = gtk_icon_theme_get_default ();
#line 76 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp28_ = _g_object_ref0 (_tmp27_);
#line 76 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		theme = _tmp28_;
#line 823 "collection-view.c"
		{
			gint size = 0;
			GdkPixbuf* _tmp29_ = NULL;
			gint _tmp30_ = 0;
			gint _tmp31_ = 0;
			GdkPixbuf* _tmp32_ = NULL;
			gint _tmp33_ = 0;
			gint _tmp34_ = 0;
			gint _tmp35_ = 0;
			GtkIconInfo* icon_info = NULL;
			GtkIconTheme* _tmp36_ = NULL;
			GEmblemedIcon* _tmp37_ = NULL;
			gint _tmp38_ = 0;
			GtkIconInfo* _tmp39_ = NULL;
			GdkPixbuf* _tmp40_ = NULL;
			GtkIconInfo* _tmp41_ = NULL;
			GdkPixbuf* _tmp42_ = NULL;
			GdkPixbuf* _tmp43_ = NULL;
#line 79 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp29_ = pixbuf;
#line 79 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp30_ = gdk_pixbuf_get_width (_tmp29_);
#line 79 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp31_ = _tmp30_;
#line 79 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp32_ = pixbuf;
#line 79 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp33_ = gdk_pixbuf_get_height (_tmp32_);
#line 79 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp34_ = _tmp33_;
#line 79 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp35_ = MAX (_tmp31_, _tmp34_);
#line 79 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			size = _tmp35_;
#line 80 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp36_ = theme;
#line 80 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp37_ = emblemed_icon;
#line 80 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp38_ = size;
#line 80 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp39_ = gtk_icon_theme_lookup_by_gicon (_tmp36_, (GIcon*) _tmp37_, _tmp38_, GTK_ICON_LOOKUP_FORCE_SIZE);
#line 80 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			icon_info = _tmp39_;
#line 82 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp41_ = icon_info;
#line 82 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp42_ = gtk_icon_info_load_icon (_tmp41_, &_inner_error_);
#line 82 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp40_ = _tmp42_;
#line 82 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 82 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
				_gtk_icon_info_free0 (icon_info);
#line 878 "collection-view.c"
				goto __catch5_g_error;
			}
#line 82 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp43_ = _tmp40_;
#line 82 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp40_ = NULL;
#line 82 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (pixbuf);
#line 82 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			pixbuf = _tmp43_;
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (_tmp40_);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_gtk_icon_info_free0 (icon_info);
#line 893 "collection-view.c"
		}
		goto __finally5;
		__catch5_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp44_ = NULL;
			const gchar* _tmp45_ = NULL;
			gchar* _tmp46_ = NULL;
			gchar* _tmp47_ = NULL;
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_error_ = _inner_error_;
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_inner_error_ = NULL;
#line 84 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp44_ = _error_;
#line 84 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp45_ = _tmp44_->message;
#line 84 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp46_ = g_strconcat ("Unable to render the emblem: ", _tmp45_, NULL);
#line 84 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp47_ = _tmp46_;
#line 84 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			g_warning ("collection-view.vala:84: %s", _tmp47_);
#line 84 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_g_free0 (_tmp47_);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_g_error_free0 (_error_);
#line 921 "collection-view.c"
		}
		__finally5:
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (theme);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (emblemed_icon);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (pixbuf);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (machine);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			emblem_icons = (_vala_array_free (emblem_icons, emblem_icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (item);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			g_clear_error (&_inner_error_);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			return;
#line 944 "collection-view.c"
		}
#line 71 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (theme);
#line 71 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (emblemed_icon);
#line 950 "collection-view.c"
	}
#line 88 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp48_ = self->priv->store;
#line 88 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp49_ = *iter;
#line 88 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp50_ = pixbuf;
#line 88 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp48_, &_tmp49_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT, _tmp50_, -1);
#line 89 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 59 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (pixbuf);
#line 59 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (machine);
#line 59 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	emblem_icons = (_vala_array_free (emblem_icons, emblem_icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 59 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 970 "collection-view.c"
}


static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self) {
	GtkTreeIter* dup;
#line 106 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	dup = g_new0 (GtkTreeIter, 1);
#line 106 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	memcpy (dup, self, sizeof (GtkTreeIter));
#line 106 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return dup;
#line 982 "collection-view.c"
}


static gpointer __gtk_tree_iter_dup0 (gpointer self) {
#line 106 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return self ? _gtk_tree_iter_dup (self) : NULL;
#line 989 "collection-view.c"
}


static void boxes_collection_view_append (BoxesCollectionView* self, const gchar* title, const gchar* info, BoxesCollectionItem* item, GtkTreeIter* result) {
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkListStore* _tmp2_ = NULL;
	GtkTreeIter _tmp3_ = {0};
	BoxesCollectionItem* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	GtkListStore* _tmp7_ = NULL;
	GtkTreeIter _tmp8_ = {0};
	const gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	GtkListStore* _tmp14_ = NULL;
	GtkTreeIter _tmp15_ = {0};
	GtkListStore* _tmp16_ = NULL;
	GtkTreeIter _tmp17_ = {0};
	BoxesCollectionItem* _tmp18_ = NULL;
	GtkTreeIter _tmp19_ = {0};
	BoxesCollectionItem* _tmp20_ = NULL;
	GtkTreeIter _tmp21_ = {0};
	GtkTreeIter* _tmp22_ = NULL;
#line 92 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 92 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (title != NULL);
#line 92 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 97 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 97 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_append (_tmp0_, &_tmp1_);
#line 97 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	iter = _tmp1_;
#line 98 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->store;
#line 98 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 98 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = item;
#line 98 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp5_ = g_strdup_printf ("%p", _tmp4_);
#line 98 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _tmp5_;
#line 98 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp2_, &_tmp3_, GD_MAIN_COLUMN_ID, _tmp6_, -1);
#line 98 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_free0 (_tmp6_);
#line 99 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->store;
#line 99 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp8_ = iter;
#line 99 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp9_ = title;
#line 99 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp7_, &_tmp8_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, _tmp9_, -1);
#line 100 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp10_ = info;
#line 100 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp10_ != NULL) {
#line 1053 "collection-view.c"
		GtkListStore* _tmp11_ = NULL;
		GtkTreeIter _tmp12_ = {0};
		const gchar* _tmp13_ = NULL;
#line 101 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp11_ = self->priv->store;
#line 101 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp12_ = iter;
#line 101 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp13_ = info;
#line 101 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		gtk_list_store_set (_tmp11_, &_tmp12_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, _tmp13_, -1);
#line 1065 "collection-view.c"
	}
#line 102 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp14_ = self->priv->store;
#line 102 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp15_ = iter;
#line 102 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp14_, &_tmp15_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, FALSE, -1);
#line 103 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp16_ = self->priv->store;
#line 103 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp17_ = iter;
#line 103 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp18_ = item;
#line 103 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp16_, &_tmp17_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, _tmp18_, -1);
#line 104 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp19_ = iter;
#line 104 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp19_);
#line 106 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp20_ = item;
#line 106 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp21_ = iter;
#line 106 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp22_ = __gtk_tree_iter_dup0 (&_tmp21_);
#line 106 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp20_, "iter", _tmp22_, g_free);
#line 108 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	*result = iter;
#line 108 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return;
#line 1097 "collection-view.c"
}


static Block18Data* block18_data_ref (Block18Data* _data18_) {
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data18_->_ref_count_);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return _data18_;
#line 1106 "collection-view.c"
}


static void block18_data_unref (void * _userdata_) {
	Block18Data* _data18_;
	_data18_ = (Block18Data*) _userdata_;
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data18_->_ref_count_)) {
#line 1115 "collection-view.c"
		BoxesCollectionView* self;
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		self = _data18_->self;
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data18_->machine);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data18_->item);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block18Data, _data18_);
#line 1127 "collection-view.c"
	}
}


static void __lambda8_ (Block18Data* _data18_) {
	BoxesCollectionView* self;
	GtkTreeIter _tmp0_ = {0};
#line 120 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = _data18_->self;
#line 122 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data18_->iter;
#line 122 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp0_);
#line 1141 "collection-view.c"
}


static void ___lambda8__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 120 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	__lambda8_ (self);
#line 1148 "collection-view.c"
}


static void __lambda9_ (Block18Data* _data18_) {
	BoxesCollectionView* self;
	GtkTreeIter _tmp0_ = {0};
#line 126 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = _data18_->self;
#line 128 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data18_->iter;
#line 128 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp0_);
#line 1161 "collection-view.c"
}


static void ___lambda9__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 126 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	__lambda9_ (self);
#line 1168 "collection-view.c"
}


static void __lambda10_ (Block18Data* _data18_) {
	BoxesCollectionView* self;
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	BoxesCollectionItem* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 132 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = _data18_->self;
#line 134 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 134 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data18_->iter;
#line 134 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data18_->item;
#line 134 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_collection_item_get_name (_tmp2_);
#line 134 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_;
#line 134 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, _tmp4_, -1);
#line 135 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 1195 "collection-view.c"
}


static void ___lambda10__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 132 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	__lambda10_ (self);
#line 1202 "collection-view.c"
}


static void __lambda11_ (Block18Data* _data18_) {
	BoxesCollectionView* self;
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	BoxesMachine* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 139 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = _data18_->self;
#line 141 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 141 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data18_->iter;
#line 141 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data18_->machine;
#line 141 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_machine_get_info (_tmp2_);
#line 141 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_;
#line 141 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, _tmp4_, -1);
#line 142 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 1229 "collection-view.c"
}


static void ___lambda11__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 139 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	__lambda11_ (self);
#line 1236 "collection-view.c"
}


static void __lambda13_ (Block18Data* _data18_) {
	BoxesCollectionView* self;
	GtkTreeIter _tmp0_ = {0};
	BoxesMachine* _tmp1_ = NULL;
#line 147 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = _data18_->self;
#line 149 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data18_->iter;
#line 149 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data18_->machine;
#line 149 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_activity (self, &_tmp0_, _tmp1_);
#line 150 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 1254 "collection-view.c"
}


static void ___lambda13__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 147 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	__lambda13_ (self);
#line 1261 "collection-view.c"
}


void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	Block18Data* _data18_;
	BoxesCollectionItem* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
	BoxesMachine* _tmp4_ = NULL;
	BoxesMachine* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	BoxesMachine* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	BoxesCollectionItem* _tmp13_ = NULL;
	GtkTreeIter _tmp14_ = {0};
	gulong pixbuf_id = 0UL;
	BoxesMachine* _tmp15_ = NULL;
	gulong _tmp16_ = 0UL;
	BoxesCollectionItem* _tmp17_ = NULL;
	gulong _tmp18_ = 0UL;
	gulong categories_id = 0UL;
	BoxesMachine* _tmp19_ = NULL;
	BoxesBoxConfig* _tmp20_ = NULL;
	gulong _tmp21_ = 0UL;
	BoxesCollectionItem* _tmp22_ = NULL;
	gulong _tmp23_ = 0UL;
	gulong name_id = 0UL;
	BoxesCollectionItem* _tmp24_ = NULL;
	gulong _tmp25_ = 0UL;
	BoxesCollectionItem* _tmp26_ = NULL;
	gulong _tmp27_ = 0UL;
	gulong info_id = 0UL;
	BoxesMachine* _tmp28_ = NULL;
	gulong _tmp29_ = 0UL;
	BoxesCollectionItem* _tmp30_ = NULL;
	gulong _tmp31_ = 0UL;
	GtkTreeIter _tmp32_ = {0};
	BoxesMachine* _tmp33_ = NULL;
	gulong under_construct_id = 0UL;
	BoxesMachine* _tmp34_ = NULL;
	gulong _tmp35_ = 0UL;
	BoxesCollectionItem* _tmp36_ = NULL;
	gulong _tmp37_ = 0UL;
	BoxesCollectionItem* _tmp38_ = NULL;
	BoxesAppWindow* _tmp39_ = NULL;
	BoxesUIState _tmp40_ = 0;
	BoxesUIState _tmp41_ = 0;
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data18_ = g_slice_new0 (Block18Data);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data18_->_ref_count_ = 1;
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data18_->self = g_object_ref (self);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_data18_->item);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data18_->item = _tmp1_;
#line 112 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data18_->item;
#line 112 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 112 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data18_->machine = _tmp3_;
#line 114 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _data18_->machine;
#line 114 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp4_ == NULL) {
#line 1340 "collection-view.c"
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 115 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp5_ = g_strdup_printf ("Cannot add item %p", &_data18_->item);
#line 115 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _tmp5_;
#line 115 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_warning ("collection-view.vala:115: %s", _tmp6_);
#line 115 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_free0 (_tmp6_);
#line 116 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		block18_data_unref (_data18_);
#line 116 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_data18_ = NULL;
#line 116 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		return;
#line 1357 "collection-view.c"
	}
#line 119 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _data18_->machine;
#line 119 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp8_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp7_);
#line 119 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _tmp8_;
#line 119 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp10_ = _data18_->machine;
#line 119 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp11_ = boxes_machine_get_info (_tmp10_);
#line 119 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp12_ = _tmp11_;
#line 119 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp13_ = _data18_->item;
#line 119 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_append (self, _tmp9_, _tmp12_, _tmp13_, &_tmp14_);
#line 119 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data18_->iter = _tmp14_;
#line 120 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp15_ = _data18_->machine;
#line 120 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp16_ = g_signal_connect_data ((GObject*) _tmp15_, "notify::pixbuf", (GCallback) ___lambda8__g_object_notify, block18_data_ref (_data18_), (GClosureNotify) block18_data_unref, 0);
#line 120 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	pixbuf_id = _tmp16_;
#line 124 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp17_ = _data18_->item;
#line 124 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp18_ = pixbuf_id;
#line 124 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp17_, "pixbuf_id", (gpointer) ((guintptr) _tmp18_), NULL);
#line 126 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp19_ = _data18_->machine;
#line 126 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp20_ = _tmp19_->config;
#line 126 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp21_ = g_signal_connect_data ((GObject*) _tmp20_, "notify::categories", (GCallback) ___lambda9__g_object_notify, block18_data_ref (_data18_), (GClosureNotify) block18_data_unref, 0);
#line 126 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	categories_id = _tmp21_;
#line 130 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp22_ = _data18_->item;
#line 130 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp23_ = categories_id;
#line 130 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp22_, "categories_id", (gpointer) ((guintptr) _tmp23_), NULL);
#line 132 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp24_ = _data18_->item;
#line 132 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp25_ = g_signal_connect_data ((GObject*) _tmp24_, "notify::name", (GCallback) ___lambda10__g_object_notify, block18_data_ref (_data18_), (GClosureNotify) block18_data_unref, 0);
#line 132 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	name_id = _tmp25_;
#line 137 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp26_ = _data18_->item;
#line 137 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp27_ = name_id;
#line 137 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp26_, "name_id", (gpointer) ((guintptr) _tmp27_), NULL);
#line 139 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp28_ = _data18_->machine;
#line 139 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp29_ = g_signal_connect_data ((GObject*) _tmp28_, "notify::info", (GCallback) ___lambda11__g_object_notify, block18_data_ref (_data18_), (GClosureNotify) block18_data_unref, 0);
#line 139 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	info_id = _tmp29_;
#line 144 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp30_ = _data18_->item;
#line 144 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp31_ = info_id;
#line 144 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp30_, "info_id", (gpointer) ((guintptr) _tmp31_), NULL);
#line 146 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp32_ = _data18_->iter;
#line 146 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp33_ = _data18_->machine;
#line 146 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_activity (self, &_tmp32_, _tmp33_);
#line 147 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp34_ = _data18_->machine;
#line 147 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp35_ = g_signal_connect_data ((GObject*) _tmp34_, "notify::under-construction", (GCallback) ___lambda13__g_object_notify, block18_data_ref (_data18_), (GClosureNotify) block18_data_unref, 0);
#line 147 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	under_construct_id = _tmp35_;
#line 152 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp36_ = _data18_->item;
#line 152 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp37_ = under_construct_id;
#line 152 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp36_, "under_construct_id", (gpointer) ((guintptr) _tmp37_), NULL);
#line 154 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp38_ = _data18_->item;
#line 154 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp39_ = self->priv->window;
#line 154 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp40_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp39_);
#line 154 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp41_ = _tmp40_;
#line 154 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp38_, _tmp41_);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	block18_data_unref (_data18_);
#line 111 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data18_ = NULL;
#line 1459 "collection-view.c"
}


static Block19Data* block19_data_ref (Block19Data* _data19_) {
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data19_->_ref_count_);
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return _data19_;
#line 1468 "collection-view.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1475 "collection-view.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_list_free (self);
#line 1484 "collection-view.c"
}


static void block19_data_unref (void * _userdata_) {
	Block19Data* _data19_;
	_data19_ = (Block19Data*) _userdata_;
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data19_->_ref_count_)) {
#line 1493 "collection-view.c"
		BoxesCollectionView* self;
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		self = _data19_->self;
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		__g_list_free__g_object_unref0_0 (_data19_->selected);
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block19Data, _data19_);
#line 1503 "collection-view.c"
	}
}


static gboolean __lambda14_ (Block19Data* _data19_, GtkTreeModel* store, GtkTreePath* path, GtkTreeIter* iter) {
	BoxesCollectionView* self;
	gboolean result = FALSE;
	BoxesCollectionItem* item = NULL;
	gboolean is_selected = FALSE;
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 160 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = _data19_->self;
#line 160 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (store != NULL, FALSE);
#line 160 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 160 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 164 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = store;
#line 164 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *iter;
#line 164 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, &is_selected, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 167 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = is_selected;
#line 167 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp3_) {
#line 1535 "collection-view.c"
		BoxesCollectionItem* _tmp4_ = NULL;
#line 167 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp4_ = item;
#line 167 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp2_ = _tmp4_ != NULL;
#line 1541 "collection-view.c"
	} else {
#line 167 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp2_ = FALSE;
#line 1545 "collection-view.c"
	}
#line 167 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp2_) {
#line 1549 "collection-view.c"
		BoxesCollectionItem* _tmp5_ = NULL;
		BoxesCollectionItem* _tmp6_ = NULL;
#line 168 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp5_ = item;
#line 168 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _g_object_ref0 (_tmp5_);
#line 168 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_data19_->selected = g_list_append (_data19_->selected, _tmp6_);
#line 1558 "collection-view.c"
	}
#line 170 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 170 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 170 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 1566 "collection-view.c"
}


static gboolean ___lambda14__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda14_ (self, model, path, iter);
#line 160 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 1575 "collection-view.c"
}


GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self) {
	GList* result = NULL;
	Block19Data* _data19_;
	GtkListStore* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data19_ = g_slice_new0 (Block19Data);
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data19_->_ref_count_ = 1;
#line 157 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data19_->self = g_object_ref (self);
#line 158 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data19_->selected = NULL;
#line 160 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 160 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp0_, ___lambda14__gtk_tree_model_foreach_func, _data19_);
#line 173 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data19_->selected;
#line 173 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data19_->selected = NULL;
#line 173 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	result = _tmp1_;
#line 173 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	block19_data_unref (_data19_);
#line 173 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data19_ = NULL;
#line 173 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 1610 "collection-view.c"
}


void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	GtkTreeIter* iter = NULL;
	BoxesCollectionItem* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
	GtkTreeIter* _tmp2_ = NULL;
	GtkTreeIter* _tmp3_ = NULL;
	GtkListStore* _tmp4_ = NULL;
	GtkTreeIter* _tmp5_ = NULL;
	GtkTreeIter _tmp6_ = {0};
	BoxesCollectionItem* _tmp7_ = NULL;
	gulong pixbuf_id = 0UL;
	BoxesCollectionItem* _tmp8_ = NULL;
	gconstpointer _tmp9_ = NULL;
	BoxesCollectionItem* _tmp10_ = NULL;
	gulong _tmp11_ = 0UL;
	gulong name_id = 0UL;
	BoxesCollectionItem* _tmp12_ = NULL;
	gconstpointer _tmp13_ = NULL;
	BoxesCollectionItem* _tmp14_ = NULL;
	gulong _tmp15_ = 0UL;
	gulong info_id = 0UL;
	BoxesCollectionItem* _tmp16_ = NULL;
	gconstpointer _tmp17_ = NULL;
	BoxesCollectionItem* _tmp18_ = NULL;
	gulong _tmp19_ = 0UL;
	gulong under_construct_id = 0UL;
	BoxesCollectionItem* _tmp20_ = NULL;
	gconstpointer _tmp21_ = NULL;
	BoxesCollectionItem* _tmp22_ = NULL;
	gulong _tmp23_ = 0UL;
	BoxesCollectionItem* _tmp24_ = NULL;
#line 176 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 176 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 177 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 177 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "iter");
#line 177 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = __gtk_tree_iter_dup0 ((GtkTreeIter*) _tmp1_);
#line 177 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 178 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 178 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp3_ == NULL) {
#line 179 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_debug ("collection-view.vala:179: item not in view or already removed");
#line 180 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_free0 (iter);
#line 180 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		return;
#line 1667 "collection-view.c"
	}
#line 183 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->store;
#line 183 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp5_ = iter;
#line 183 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp6_ = *_tmp5_;
#line 183 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_remove (_tmp4_, &_tmp6_);
#line 184 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp7_ = item;
#line 184 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp7_, "iter", NULL, g_free);
#line 186 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item;
#line 186 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp9_ = g_object_get_data ((GObject*) _tmp8_, "pixbuf_id");
#line 186 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	pixbuf_id = (gulong) ((guintptr) _tmp9_);
#line 187 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp10_ = item;
#line 187 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp11_ = pixbuf_id;
#line 187 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp10_, _tmp11_);
#line 188 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp12_ = item;
#line 188 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp13_ = g_object_get_data ((GObject*) _tmp12_, "name_id");
#line 188 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	name_id = (gulong) ((guintptr) _tmp13_);
#line 189 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp14_ = item;
#line 189 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp15_ = name_id;
#line 189 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp14_, _tmp15_);
#line 190 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp16_ = item;
#line 190 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp17_ = g_object_get_data ((GObject*) _tmp16_, "info_id");
#line 190 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	info_id = (gulong) ((guintptr) _tmp17_);
#line 191 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp18_ = item;
#line 191 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp19_ = info_id;
#line 191 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp18_, _tmp19_);
#line 192 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp20_ = item;
#line 192 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp21_ = g_object_get_data ((GObject*) _tmp20_, "under_construct_id");
#line 192 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	under_construct_id = (gulong) ((guintptr) _tmp21_);
#line 193 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp22_ = item;
#line 193 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp23_ = under_construct_id;
#line 193 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp22_, _tmp23_);
#line 195 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp24_ = item;
#line 195 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if ((G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp24_) : NULL) != NULL) {
#line 1733 "collection-view.c"
		BoxesMachine* machine = NULL;
		BoxesCollectionItem* _tmp25_ = NULL;
		BoxesMachine* _tmp26_ = NULL;
		gulong categories_id = 0UL;
		BoxesCollectionItem* _tmp27_ = NULL;
		gconstpointer _tmp28_ = NULL;
		BoxesMachine* _tmp29_ = NULL;
		BoxesBoxConfig* _tmp30_ = NULL;
		gulong _tmp31_ = 0UL;
#line 196 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp25_ = item;
#line 196 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp26_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp25_) : NULL);
#line 196 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		machine = _tmp26_;
#line 197 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp27_ = item;
#line 197 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp28_ = g_object_get_data ((GObject*) _tmp27_, "categories_id");
#line 197 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		categories_id = (gulong) ((guintptr) _tmp28_);
#line 198 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp29_ = machine;
#line 198 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp30_ = _tmp29_->config;
#line 198 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp31_ = categories_id;
#line 198 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_signal_handler_disconnect ((GObject*) _tmp30_, _tmp31_);
#line 195 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (machine);
#line 1765 "collection-view.c"
	}
#line 176 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_free0 (iter);
#line 1769 "collection-view.c"
}


static BoxesCollectionItem* boxes_collection_view_get_item_for_iter (BoxesCollectionView* self, GtkTreeIter* iter) {
	BoxesCollectionItem* result = NULL;
	GValue value = {0};
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GValue _tmp2_ = {0};
	GValue _tmp3_ = {0};
	BoxesCollectionItem* _tmp4_ = NULL;
#line 202 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 202 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, NULL);
#line 205 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 205 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *iter;
#line 205 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get_value ((GtkTreeModel*) _tmp0_, &_tmp1_, (gint) BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &_tmp2_);
#line 205 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 205 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	value = _tmp2_;
#line 207 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = value;
#line 207 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _g_object_ref0 (g_value_get_object (&_tmp3_));
#line 207 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	result = _tmp4_;
#line 207 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 207 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 1805 "collection-view.c"
}


static BoxesCollectionItem* boxes_collection_view_get_item_for_path (BoxesCollectionView* self, GtkTreePath* path) {
	BoxesCollectionItem* result = NULL;
	GtkTreeIter filter_iter = {0};
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_ = NULL;
	GtkTreePath* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	GtkTreeModelFilter* _tmp3_ = NULL;
	GtkTreeIter _tmp4_ = {0};
	GtkTreeIter _tmp5_ = {0};
	GtkTreeIter _tmp6_ = {0};
	BoxesCollectionItem* _tmp7_ = NULL;
#line 211 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 211 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 214 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 214 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = path;
#line 214 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp2_, _tmp1_);
#line 214 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	filter_iter = _tmp2_;
#line 215 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->priv->model_filter;
#line 215 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = filter_iter;
#line 215 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp3_, &_tmp5_, &_tmp4_);
#line 215 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	iter = _tmp5_;
#line 217 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp6_ = iter;
#line 217 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp7_ = boxes_collection_view_get_item_for_iter (self, &_tmp6_);
#line 217 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	result = _tmp7_;
#line 217 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 1849 "collection-view.c"
}


static gboolean boxes_collection_view_model_visible (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* iter) {
	gboolean result = FALSE;
	BoxesCollectionItem* item = NULL;
	GtkTreeIter _tmp0_ = {0};
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesApp* _tmp3_ = NULL;
	BoxesCollectionFilter* _tmp4_ = NULL;
	BoxesCollectionItem* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 220 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 220 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (model != NULL, FALSE);
#line 220 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 221 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = *iter;
#line 221 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_item_for_iter (self, &_tmp0_);
#line 221 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	item = _tmp1_;
#line 222 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = item;
#line 222 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp2_ == NULL) {
#line 223 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 223 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item);
#line 223 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		return result;
#line 1885 "collection-view.c"
	}
#line 225 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 225 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_->filter;
#line 225 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp5_ = item;
#line 225 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp6_ = boxes_collection_filter_filter (_tmp4_, _tmp5_);
#line 225 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	result = _tmp6_;
#line 225 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 225 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 1901 "collection-view.c"
}


void boxes_collection_view_refilter (BoxesCollectionView* self) {
	GtkTreeModelFilter* _tmp0_ = NULL;
#line 228 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 229 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 229 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_refilter (_tmp0_);
#line 1913 "collection-view.c"
}


void boxes_collection_view_activate_first_item (BoxesCollectionView* self) {
	GtkTreeModelFilter* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 232 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 233 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 233 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = gtk_tree_model_iter_n_children ((GtkTreeModel*) _tmp0_, NULL);
#line 233 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ == 1) {
#line 1928 "collection-view.c"
		GtkTreePath* path = NULL;
		GtkTreePath* _tmp2_ = NULL;
		GtkWidget* _tmp3_ = NULL;
		GtkTreePath* _tmp4_ = NULL;
#line 234 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp2_ = gtk_tree_path_new_from_string ("0");
#line 234 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		path = _tmp2_;
#line 235 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp3_ = gd_main_view_get_generic_view ((GdMainView*) self);
#line 235 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp4_ = path;
#line 235 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		gtk_icon_view_item_activated (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, gtk_icon_view_get_type ()) ? ((GtkIconView*) _tmp3_) : NULL, _tmp4_);
#line 233 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_gtk_tree_path_free0 (path);
#line 1945 "collection-view.c"
	}
}


static gint __lambda15_ (BoxesCollectionView* self, GtkTreeModel* store, GtkTreeIter* a, GtkTreeIter* b) {
	gint result = 0;
	BoxesCollectionItem* item_a = NULL;
	BoxesCollectionItem* item_b = NULL;
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkTreeModel* _tmp2_ = NULL;
	GtkTreeIter _tmp3_ = {0};
	gboolean _tmp4_ = FALSE;
	BoxesCollectionItem* _tmp5_ = NULL;
	BoxesCollectionItem* _tmp7_ = NULL;
	BoxesCollectionItem* _tmp8_ = NULL;
	gint _tmp9_ = 0;
#line 250 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (store != NULL, 0);
#line 250 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 250 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 253 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = store;
#line 253 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *a;
#line 253 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item_a, -1);
#line 254 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = store;
#line 254 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = *b;
#line 254 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp2_, &_tmp3_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item_b, -1);
#line 256 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp5_ = item_a;
#line 256 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp5_ == NULL) {
#line 256 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp4_ = TRUE;
#line 1987 "collection-view.c"
	} else {
		BoxesCollectionItem* _tmp6_ = NULL;
#line 256 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp6_ = item_b;
#line 256 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp4_ = _tmp6_ == NULL;
#line 1994 "collection-view.c"
	}
#line 256 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp4_) {
#line 257 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		result = 0;
#line 257 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item_b);
#line 257 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item_a);
#line 257 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		return result;
#line 2006 "collection-view.c"
	}
#line 259 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp7_ = item_a;
#line 259 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item_b;
#line 259 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp9_ = boxes_collection_item_compare (_tmp7_, _tmp8_);
#line 259 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	result = _tmp9_;
#line 259 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item_b);
#line 259 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item_a);
#line 259 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 2022 "collection-view.c"
}


static gint ___lambda15__gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self) {
	gint result;
	result = __lambda15_ ((BoxesCollectionView*) self, model, a, b);
#line 250 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 2031 "collection-view.c"
}


static void __lambda16_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_ = NULL;
#line 263 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 263 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2041 "collection-view.c"
}


static void ___lambda16__gtk_tree_model_row_deleted (GtkTreeModel* _sender, GtkTreePath* path, gpointer self) {
#line 262 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	__lambda16_ ((BoxesCollectionView*) self);
#line 2048 "collection-view.c"
}


static void __lambda17_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_ = NULL;
#line 266 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 266 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2058 "collection-view.c"
}


static void ___lambda17__gtk_tree_model_row_inserted (GtkTreeModel* _sender, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
#line 265 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	__lambda17_ ((BoxesCollectionView*) self);
#line 2065 "collection-view.c"
}


static gboolean _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = boxes_collection_view_model_visible ((BoxesCollectionView*) self, model, iter);
#line 270 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 2074 "collection-view.c"
}


static void __lambda18_ (BoxesCollectionView* self, GdMainView* view, const gchar* id, GtkTreePath* path) {
	BoxesCollectionItem* item = NULL;
	GtkTreePath* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	BoxesCollectionItem* _tmp3_ = NULL;
	BoxesAppWindow* _tmp7_ = NULL;
	BoxesCollectionItem* _tmp8_ = NULL;
#line 275 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (view != NULL);
#line 275 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (id != NULL);
#line 275 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (path != NULL);
#line 276 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = path;
#line 276 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_item_for_path (self, _tmp0_);
#line 276 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	item = _tmp1_;
#line 277 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = item;
#line 277 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 2102 "collection-view.c"
		BoxesCollectionItem* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		gboolean _tmp6_ = FALSE;
#line 277 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp4_ = item;
#line 277 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp5_ = boxes_libvirt_machine_get_importing (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp4_) : NULL);
#line 277 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _tmp5_;
#line 277 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp2_ = _tmp6_;
#line 2114 "collection-view.c"
	} else {
#line 277 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp2_ = FALSE;
#line 2118 "collection-view.c"
	}
#line 277 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp2_) {
#line 278 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item);
#line 278 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		return;
#line 2126 "collection-view.c"
	}
#line 279 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->window;
#line 279 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item;
#line 279 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_app_window_select_item (_tmp7_, _tmp8_);
#line 275 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 2136 "collection-view.c"
}


static void ___lambda18__gd_main_view_item_activated (GdMainView* _sender, const gchar* object, GtkTreePath* p0, gpointer self) {
#line 275 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	__lambda18_ ((BoxesCollectionView*) self, _sender, object, p0);
#line 2143 "collection-view.c"
}


static void __lambda157_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_ = NULL;
#line 282 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 283 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 283 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2155 "collection-view.c"
}


static void ___lambda157__gd_main_view_view_selection_changed (GdMainView* _sender, gpointer self) {
#line 281 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	__lambda157_ ((BoxesCollectionView*) self);
#line 2162 "collection-view.c"
}


static void __lambda158_ (BoxesCollectionView* self) {
	BoxesAppWindow* _tmp0_ = NULL;
#line 286 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->window;
#line 286 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_app_window_set_selection_mode (_tmp0_, TRUE);
#line 2172 "collection-view.c"
}


static void ___lambda158__gd_main_view_selection_mode_request (GdMainView* _sender, gpointer self) {
#line 285 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	__lambda158_ ((BoxesCollectionView*) self);
#line 2179 "collection-view.c"
}


static void boxes_collection_view_setup_view (BoxesCollectionView* self) {
	GtkListStore* _tmp0_ = NULL;
	GtkListStore* _tmp1_ = NULL;
	GtkListStore* _tmp2_ = NULL;
	GtkListStore* _tmp3_ = NULL;
	GtkListStore* _tmp4_ = NULL;
	GtkListStore* _tmp5_ = NULL;
	GtkTreeModelFilter* _tmp6_ = NULL;
	GtkTreeModelFilter* _tmp7_ = NULL;
	GtkTreeModelFilter* _tmp8_ = NULL;
	GtkStyleContext* _tmp9_ = NULL;
#line 239 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 240 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = gtk_list_store_new ((gint) BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_LONG, G_TYPE_BOOLEAN, G_TYPE_UINT, BOXES_TYPE_COLLECTION_ITEM, -1);
#line 240 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->store);
#line 240 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self->priv->store = _tmp0_;
#line 250 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->store;
#line 250 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_sortable_set_default_sort_func ((GtkTreeSortable*) _tmp1_, ___lambda15__gtk_tree_iter_compare_func, g_object_ref (self), g_object_unref);
#line 261 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->store;
#line 261 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable*) _tmp2_, GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
#line 262 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->priv->store;
#line 262 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkTreeModel*) _tmp3_, "row-deleted", (GCallback) ___lambda16__gtk_tree_model_row_deleted, self, 0);
#line 265 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->store;
#line 265 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkTreeModel*) _tmp4_, "row-inserted", (GCallback) ___lambda17__gtk_tree_model_row_inserted, self, 0);
#line 269 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp5_ = self->priv->store;
#line 269 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp6_ = (GtkTreeModelFilter*) gtk_tree_model_filter_new ((GtkTreeModel*) _tmp5_, NULL);
#line 269 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 269 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self->priv->model_filter = _tmp6_;
#line 270 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->model_filter;
#line 270 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_set_visible_func (_tmp7_, _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func, g_object_ref (self), g_object_unref);
#line 272 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_view_type ((GdMainView*) self, GD_MAIN_VIEW_ICON);
#line 273 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp8_ = self->priv->model_filter;
#line 273 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_model ((GdMainView*) self, (GtkTreeModel*) _tmp8_);
#line 274 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 274 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_style_context_add_class (_tmp9_, "content-bg");
#line 275 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GdMainView*) self, "item-activated", (GCallback) ___lambda18__gd_main_view_item_activated, self, 0);
#line 281 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GdMainView*) self, "view-selection-changed", (GCallback) ___lambda157__gd_main_view_view_selection_changed, self, 0);
#line 285 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GdMainView*) self, "selection-mode-request", (GCallback) ___lambda158__gd_main_view_selection_mode_request, self, 0);
#line 288 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 2248 "collection-view.c"
}


static Block20Data* block20_data_ref (Block20Data* _data20_) {
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data20_->_ref_count_);
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return _data20_;
#line 2257 "collection-view.c"
}


static void block20_data_unref (void * _userdata_) {
	Block20Data* _data20_;
	_data20_ = (Block20Data*) _userdata_;
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data20_->_ref_count_)) {
#line 2266 "collection-view.c"
		BoxesCollectionView* self;
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		self = _data20_->self;
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block20Data, _data20_);
#line 2274 "collection-view.c"
	}
}


static gboolean __lambda159_ (Block20Data* _data20_, GtkTreeModel* filter_model, GtkTreePath* filter_path, GtkTreeIter* filter_iter) {
	BoxesCollectionView* self;
	gboolean result = FALSE;
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkTreeIter _tmp2_ = {0};
	gboolean selected = FALSE;
	BoxesSelectionCriteria _tmp3_ = 0;
	GtkListStore* _tmp12_ = NULL;
	GtkTreeIter _tmp13_ = {0};
	gboolean _tmp14_ = FALSE;
#line 294 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = _data20_->self;
#line 294 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_model != NULL, FALSE);
#line 294 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_path != NULL, FALSE);
#line 294 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_iter != NULL, FALSE);
#line 296 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 296 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *filter_iter;
#line 296 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp0_, &_tmp2_, &_tmp1_);
#line 296 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 298 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _data20_->selection;
#line 298 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	switch (_tmp3_) {
#line 2311 "collection-view.c"
		default:
#line 298 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_ALL:
#line 2315 "collection-view.c"
		{
#line 301 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			selected = TRUE;
#line 302 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			break;
#line 2321 "collection-view.c"
		}
#line 298 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_NONE:
#line 2325 "collection-view.c"
		{
#line 304 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			selected = FALSE;
#line 305 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			break;
#line 2331 "collection-view.c"
		}
#line 298 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_RUNNING:
#line 2335 "collection-view.c"
		{
			BoxesCollectionItem* item = NULL;
			GtkListStore* _tmp4_ = NULL;
			GtkTreeIter _tmp5_ = {0};
			gboolean _tmp6_ = FALSE;
			gboolean _tmp7_ = FALSE;
			BoxesCollectionItem* _tmp8_ = NULL;
#line 308 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp4_ = self->priv->store;
#line 308 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp5_ = iter;
#line 308 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			gtk_tree_model_get ((GtkTreeModel*) _tmp4_, &_tmp5_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 309 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_tmp8_ = item;
#line 309 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			if (_tmp8_ != NULL) {
#line 2353 "collection-view.c"
				BoxesCollectionItem* _tmp9_ = NULL;
#line 309 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
				_tmp9_ = item;
#line 309 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
				_tmp7_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, BOXES_TYPE_MACHINE);
#line 2359 "collection-view.c"
			} else {
#line 309 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
				_tmp7_ = FALSE;
#line 2363 "collection-view.c"
			}
#line 309 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			if (_tmp7_) {
#line 2367 "collection-view.c"
				BoxesCollectionItem* _tmp10_ = NULL;
				gboolean _tmp11_ = FALSE;
#line 310 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
				_tmp10_ = item;
#line 310 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
				_tmp11_ = boxes_machine_is_running (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp10_) : NULL);
#line 310 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
				_tmp6_ = _tmp11_;
#line 2376 "collection-view.c"
			} else {
#line 309 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
				_tmp6_ = FALSE;
#line 2380 "collection-view.c"
			}
#line 309 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			selected = _tmp6_;
#line 311 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (item);
#line 311 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
			break;
#line 2388 "collection-view.c"
		}
	}
#line 313 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp12_ = self->priv->store;
#line 313 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp13_ = iter;
#line 313 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp14_ = selected;
#line 313 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp12_, &_tmp13_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, _tmp14_, -1);
#line 314 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 314 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 2403 "collection-view.c"
}


static gboolean ___lambda159__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda159_ (self, model, path, iter);
#line 294 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 2412 "collection-view.c"
}


void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection) {
	Block20Data* _data20_;
	BoxesSelectionCriteria _tmp0_ = 0;
	BoxesAppWindow* _tmp1_ = NULL;
	GtkTreeModelFilter* _tmp2_ = NULL;
	BoxesApp* _tmp3_ = NULL;
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data20_ = g_slice_new0 (Block20Data);
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data20_->_ref_count_ = 1;
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data20_->self = g_object_ref (self);
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = selection;
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data20_->selection = _tmp0_;
#line 292 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->window;
#line 292 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_app_window_set_selection_mode (_tmp1_, TRUE);
#line 294 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->model_filter;
#line 294 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp2_, ___lambda159__gtk_tree_model_foreach_func, _data20_);
#line 316 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 317 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 317 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp3_, "selected-items");
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	block20_data_unref (_data20_);
#line 291 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data20_ = NULL;
#line 2452 "collection-view.c"
}


static Block21Data* block21_data_ref (Block21Data* _data21_) {
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data21_->_ref_count_);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return _data21_;
#line 2461 "collection-view.c"
}


static void block21_data_unref (void * _userdata_) {
	Block21Data* _data21_;
	_data21_ = (Block21Data*) _userdata_;
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data21_->_ref_count_)) {
#line 2470 "collection-view.c"
		BoxesCollectionView* self;
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		self = _data21_->self;
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data21_->machine);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block21Data, _data21_);
#line 2480 "collection-view.c"
	}
}


static gboolean __lambda12_ (Block21Data* _data21_) {
	BoxesCollectionView* self;
	gboolean result = FALSE;
	GtkTreeIter* machine_iter = NULL;
	BoxesMachine* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
	GtkTreeIter* _tmp2_ = NULL;
	GtkTreeIter* _tmp3_ = NULL;
	GtkListStore* _tmp4_ = NULL;
	GtkTreeIter* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	GtkTreeIter _tmp7_ = {0};
#line 335 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = _data21_->self;
#line 336 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data21_->machine;
#line 336 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "iter");
#line 336 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = __gtk_tree_iter_dup0 ((GtkTreeIter*) _tmp1_);
#line 336 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	machine_iter = _tmp2_;
#line 337 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = machine_iter;
#line 337 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp3_ == NULL) {
#line 338 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 338 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_g_free0 (machine_iter);
#line 338 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		return result;
#line 2517 "collection-view.c"
	}
#line 340 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->store;
#line 340 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp5_ = machine_iter;
#line 340 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _data21_->pulse;
#line 340 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data21_->pulse = _tmp6_ + 1;
#line 340 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp7_ = *_tmp5_;
#line 340 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp4_, &_tmp7_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, _tmp6_, -1);
#line 341 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 343 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	result = TRUE;
#line 343 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_free0 (machine_iter);
#line 343 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 2539 "collection-view.c"
}


static gboolean ___lambda12__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda12_ (self);
#line 335 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 2548 "collection-view.c"
}


static void boxes_collection_view_setup_activity (BoxesCollectionView* self, GtkTreeIter* iter, BoxesMachine* machine) {
	Block21Data* _data21_;
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
	guint activity_timeout = 0U;
	BoxesMachine* _tmp2_ = NULL;
	gconstpointer _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	BoxesMachine* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
	GtkListStore* _tmp12_ = NULL;
	GtkTreeIter _tmp13_ = {0};
	gint _tmp14_ = 0;
	guint _tmp15_ = 0U;
	BoxesMachine* _tmp16_ = NULL;
	guint _tmp17_ = 0U;
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (iter != NULL);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (machine != NULL);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data21_ = g_slice_new0 (Block21Data);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data21_->_ref_count_ = 1;
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data21_->self = g_object_ref (self);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = machine;
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_data21_->machine);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data21_->machine = _tmp1_;
#line 321 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data21_->machine;
#line 321 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp3_ = g_object_get_data ((GObject*) _tmp2_, "activity_timeout");
#line 321 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	activity_timeout = (guint) ((guintptr) _tmp3_);
#line 322 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp4_ = activity_timeout;
#line 322 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (_tmp4_ > ((guint) 0)) {
#line 2599 "collection-view.c"
		guint _tmp5_ = 0U;
		BoxesMachine* _tmp6_ = NULL;
#line 323 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp5_ = activity_timeout;
#line 323 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_source_remove (_tmp5_);
#line 324 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _data21_->machine;
#line 324 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_object_set_data_full ((GObject*) _tmp6_, "activity_timeout", (gpointer) ((guintptr) ((guint) 0)), NULL);
#line 2610 "collection-view.c"
	}
#line 327 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _data21_->machine;
#line 327 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp8_ = boxes_machine_get_under_construction (_tmp7_);
#line 327 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _tmp8_;
#line 327 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	if (!_tmp9_) {
#line 2620 "collection-view.c"
		GtkListStore* _tmp10_ = NULL;
		GtkTreeIter _tmp11_ = {0};
#line 328 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp10_ = self->priv->store;
#line 328 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_tmp11_ = *iter;
#line 328 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		gtk_list_store_set (_tmp10_, &_tmp11_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, 0, -1);
#line 330 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		block21_data_unref (_data21_);
#line 330 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		_data21_ = NULL;
#line 330 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		return;
#line 2635 "collection-view.c"
	}
#line 333 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data21_->pulse = 1;
#line 334 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp12_ = self->priv->store;
#line 334 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp13_ = *iter;
#line 334 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp14_ = _data21_->pulse;
#line 334 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data21_->pulse = _tmp14_ + 1;
#line 334 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp12_, &_tmp13_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, _tmp14_, -1);
#line 335 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp15_ = g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) 150, ___lambda12__gsource_func, block21_data_ref (_data21_), block21_data_unref);
#line 335 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	activity_timeout = _tmp15_;
#line 345 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp16_ = _data21_->machine;
#line 345 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp17_ = activity_timeout;
#line 345 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp16_, "activity_timeout", (gpointer) ((guintptr) _tmp17_), NULL);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	block21_data_unref (_data21_);
#line 320 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_data21_ = NULL;
#line 2663 "collection-view.c"
}


BoxesCollectionView* boxes_collection_view_construct (GType object_type) {
	BoxesCollectionView * self = NULL;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) g_object_new (object_type, NULL);
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return self;
#line 2673 "collection-view.c"
}


BoxesCollectionView* boxes_collection_view_new (void) {
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return boxes_collection_view_construct (BOXES_TYPE_COLLECTION_VIEW);
#line 2680 "collection-view.c"
}


static BoxesUIState boxes_collection_view_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 10 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 10 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 10 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	result = _tmp0_;
#line 10 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 2696 "collection-view.c"
}


static void boxes_collection_view_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 10 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 10 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = value;
#line 10 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 10 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 2711 "collection-view.c"
}


static BoxesUIState boxes_collection_view_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 11 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 11 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->_ui_state;
#line 11 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	result = _tmp0_;
#line 11 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 2727 "collection-view.c"
}


static void boxes_collection_view_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 11 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 11 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = value;
#line 11 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self->priv->_ui_state = _tmp0_;
#line 11 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 2742 "collection-view.c"
}


BoxesCategory* boxes_collection_view_get_category (BoxesCollectionView* self) {
	BoxesCategory* result;
	BoxesCategory* _tmp0_ = NULL;
#line 17 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 17 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->_category;
#line 17 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	result = _tmp0_;
#line 17 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return result;
#line 2757 "collection-view.c"
}


void boxes_collection_view_set_category (BoxesCollectionView* self, BoxesCategory* value) {
	BoxesCategory* _tmp0_ = NULL;
	BoxesCategory* _tmp1_ = NULL;
#line 18 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 19 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = value;
#line 19 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 19 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->_category);
#line 19 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self->priv->_category = _tmp1_;
#line 18 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "category");
#line 2776 "collection-view.c"
}


static void _boxes_collection_view_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 41 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_ui_state_changed ((BoxesCollectionView*) self);
#line 2783 "collection-view.c"
}


static GObject * boxes_collection_view_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesCollectionView * self;
	const gchar* _tmp0_ = NULL;
	BoxesCategory* _tmp1_ = NULL;
	BoxesCategory* _tmp2_ = NULL;
#line 38 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	parent_class = G_OBJECT_CLASS (boxes_collection_view_parent_class);
#line 38 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 38 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 39 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _ ("New and Recent");
#line 39 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_category_new (_tmp0_, BOXES_CATEGORY_KIND_NEW);
#line 39 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _tmp1_;
#line 39 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_set_category (self, _tmp2_);
#line 39 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_tmp2_);
#line 40 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_view (self);
#line 41 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_collection_view_ui_state_changed_g_object_notify, self, 0);
#line 38 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	return obj;
#line 2816 "collection-view.c"
}


static void boxes_collection_view_class_init (BoxesCollectionViewClass * klass) {
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_type_class_add_private (klass, sizeof (BoxesCollectionViewPrivate));
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_collection_view_get_property;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_collection_view_set_property;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_collection_view_constructor;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_collection_view_finalize;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_CATEGORY, g_param_spec_object ("category", "category", "category", BOXES_TYPE_CATEGORY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2839 "collection-view.c"
}


static void boxes_collection_view_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	iface->get_previous_ui_state = boxes_collection_view_real_get_previous_ui_state;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	iface->set_previous_ui_state = boxes_collection_view_real_set_previous_ui_state;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	iface->get_ui_state = boxes_collection_view_real_get_ui_state;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	iface->set_ui_state = boxes_collection_view_real_set_ui_state;
#line 2854 "collection-view.c"
}


static void boxes_collection_view_instance_init (BoxesCollectionView * self) {
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self->priv = BOXES_COLLECTION_VIEW_GET_PRIVATE (self);
#line 2861 "collection-view.c"
}


static void boxes_collection_view_finalize (GObject* obj) {
	BoxesCollectionView * self;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->window);
#line 15 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->_category);
#line 35 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->store);
#line 36 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (boxes_collection_view_parent_class)->finalize (obj);
#line 2879 "collection-view.c"
}


GType boxes_collection_view_get_type (void) {
	static volatile gsize boxes_collection_view_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_view_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesCollectionViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_collection_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesCollectionView), 0, (GInstanceInitFunc) boxes_collection_view_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_collection_view_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_collection_view_type_id;
		boxes_collection_view_type_id = g_type_register_static (gd_main_view_get_type (), "BoxesCollectionView", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_collection_view_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_collection_view_type_id__volatile, boxes_collection_view_type_id);
	}
	return boxes_collection_view_type_id__volatile;
}


static void _vala_boxes_collection_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesCollectionView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	switch (property_id) {
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE:
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_UI_STATE:
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_CATEGORY:
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		g_value_set_object (value, boxes_collection_view_get_category (self));
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		break;
#line 2920 "collection-view.c"
		default:
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		break;
#line 2926 "collection-view.c"
	}
}


static void _vala_boxes_collection_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesCollectionView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
	switch (property_id) {
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE:
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_UI_STATE:
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_CATEGORY:
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		boxes_collection_view_set_category (self, g_value_get_object (value));
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		break;
#line 2954 "collection-view.c"
		default:
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 9 "/home/mclasen/Sources/gnome-boxes/src/collection-view.vala"
		break;
#line 2960 "collection-view.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



